summaryrefslogtreecommitdiffstats
path: root/templates/annotated/menuapp3.py
diff options
context:
space:
mode:
Diffstat (limited to 'templates/annotated/menuapp3.py')
-rw-r--r--templates/annotated/menuapp3.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/templates/annotated/menuapp3.py b/templates/annotated/menuapp3.py
index 84a90f7..59b0a6a 100644
--- a/templates/annotated/menuapp3.py
+++ b/templates/annotated/menuapp3.py
@@ -43,7 +43,7 @@ import sys
from qt import TQPopupMenu, SIGNAL
-from tdecore import TDEApplication, TDECmdLineArgs, KAboutData, i18n
+from tdecore import TDEApplication, TDECmdLineArgs, TDEAboutData, i18n
from tdeui import KMainWindow, KMessageBox, KStdAction, KAction, KActionCollection
STATUSBAR_LEFT = 1
@@ -188,11 +188,11 @@ description = "A basic application template"
version = "1.0"
# To use the XMLGUI mechanism, you MUST provide an appName
# (the first argument to KAboutData below) - the XML spec
# for the interface will be in <appName>ui.rc (don't forget
# the "ui" suffix to the application name)
-aboutData = KAboutData ("menuapp3", "",\
- version, description, KAboutData.License_GPL,\
+aboutData = TDEAboutData ("menuapp3", "",\
+ version, description, TDEAboutData.License_GPL,\
"(C) 2003 whoever the author is")
aboutData.addAuthor ("author1", "whatever they did", "email@somedomain")
@@ -188,11 +188,11 @@ description = "A basic application template"
version = "1.0"
# To use the XMLGUI mechanism, you MUST provide an appName
-# (the first argument to KAboutData below) - the XML spec
+# (the first argument to TDEAboutData below) - the XML spec
# for the interface will be in <appName>ui.rc (don't forget
# the "ui" suffix to the application name)